@@ -1,39 +1,11 @@
-# Copyright 2021 QuantumBlack Visual Analytics Limited
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
-# NONINFRINGEMENT. IN NO EVENT WILL THE LICENSOR OR OTHER CONTRIBUTORS
-# BE LIABLE FOR ANY CLAIM, DAMAGES, OR OTHER LIABILITY, WHETHER IN AN
-# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF, OR IN
-# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
-# The QuantumBlack Visual Analytics Limited ("QuantumBlack") name and logo
-# (either separately or in combination, "QuantumBlack Trademarks") are
-# trademarks of QuantumBlack. The License does not grant you any right or
-# license to the QuantumBlack Trademarks. You may not use the QuantumBlack
-# Trademarks or any confusingly similar mark as a trademark for your product,
-# or use the QuantumBlack Trademarks in any other manner that might cause
-# confusion in the marketplace, including but not limited to in advertising,
-# on websites, or on software.
-#
-# See the License for the specific language governing permissions and
-# limitations under the License.
-
-
-"""``MatplotlibWriter`` saves matplotlib objects as image file(s) to an underlying
-filesystem (e.g. local, S3, GCS)."""
+"""``MatplotlibWriter`` saves one or more Matplotlib objects as image
+files to an underlying filesystem (e.g. local, S3, GCS)."""
 
 import io
 from copy import deepcopy
 from pathlib import PurePosixPath
 from typing import Any, Dict, List, Union
+from warnings import warn
 
 import fsspec
 import matplotlib.pyplot as plt
@@ -48,8 +20,8 @@ from kedro.io.core import (
 
 
 class MatplotlibWriter(AbstractVersionedDataSet):
-    """``MatplotlibWriter`` saves matplotlib objects to image file(s) in an underlying
-    filesystem (e.g. local, S3, GCS).
+    """``MatplotlibWriter`` saves one or more Matplotlib objects as
+    image files to an underlying filesystem (e.g. local, S3, GCS).
 
     Example:
     ::
@@ -99,13 +71,14 @@ class MatplotlibWriter(AbstractVersionedDataSet):
         credentials: Dict[str, Any] = None,
         save_args: Dict[str, Any] = None,
         version: Version = None,
+        overwrite: bool = False,
     ) -> None:
         """Creates a new instance of ``MatplotlibWriter``.
 
         Args:
-            filepath: Filepath in POSIX format to a matplot object file(s) prefixed with a protocol
-                like `s3://`. If prefix is not provided, `file` protocol (local filesystem) will be
-                used. The prefix should be any protocol supported by ``fsspec``.
+            filepath: Filepath in POSIX format to save Matplotlib objects to, prefixed with a
+                protocol like `s3://`. If prefix is not provided, `file` protocol (local filesystem)
+                will be used. The prefix should be any protocol supported by ``fsspec``.
             fs_args: Extra arguments to pass into underlying filesystem class constructor
                 (e.g. `{"project": "my-project"}` for ``GCSFileSystem``), as well as
                 to pass to the filesystem's `open` method through nested key `open_args_save`.
@@ -121,6 +94,9 @@ class MatplotlibWriter(AbstractVersionedDataSet):
                 ``kedro.io.core.Version``. If its ``load`` attribute is
                 None, the latest version will be loaded. If its ``save``
                 attribute is None, save version will be autogenerated.
+            overwrite: If True, any existing image files will be removed.
+                Only relevant when saving multiple Matplotlib objects at
+                once.
         """
         _credentials = deepcopy(credentials) or {}
         _fs_args = deepcopy(fs_args) or {}
@@ -148,6 +124,15 @@ class MatplotlibWriter(AbstractVersionedDataSet):
         if save_args is not None:
             self._save_args.update(save_args)
 
+        if overwrite and version is not None:
+            warn(
+                "Setting `overwrite=True` is ineffective if versioning "
+                "is enabled, since the versioned path must not already "
+                "exist; overriding flag with `overwrite=False` instead."
+            )
+            overwrite = False
+        self._overwrite = overwrite
+
     def _describe(self) -> Dict[str, Any]:
         return dict(
             filepath=self._filepath,
@@ -164,6 +149,9 @@ class MatplotlibWriter(AbstractVersionedDataSet):
     ) -> None:
         save_path = self._get_save_path()
 
+        if isinstance(data, (list, dict)) and self._overwrite and self._exists():
+            self._fs.rm(get_filepath_str(save_path, self._protocol), recursive=True)
+
         if isinstance(data, list):
             for index, plot in enumerate(data):
                 full_key_path = get_filepath_str(
