@@ -1,31 +1,3 @@
-# Copyright 2021 QuantumBlack Visual Analytics Limited
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
-# NONINFRINGEMENT. IN NO EVENT WILL THE LICENSOR OR OTHER CONTRIBUTORS
-# BE LIABLE FOR ANY CLAIM, DAMAGES, OR OTHER LIABILITY, WHETHER IN AN
-# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF, OR IN
-# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
-# The QuantumBlack Visual Analytics Limited ("QuantumBlack") name and logo
-# (either separately or in combination, "QuantumBlack Trademarks") are
-# trademarks of QuantumBlack. The License does not grant you any right or
-# license to the QuantumBlack Trademarks. You may not use the QuantumBlack
-# Trademarks or any confusingly similar mark as a trademark for your product,
-# or use the QuantumBlack Trademarks in any other manner that might cause
-# confusion in the marketplace, including but not limited to in advertising,
-# on websites, or on software.
-#
-# See the License for the specific language governing permissions and
-# limitations under the License.
-
 """``AppendableExcelDataSet`` loads/saves data from/to a local Excel file opened in append mode.
 It uses pandas to handle the Excel file.
 """
@@ -42,7 +14,32 @@ class AppendableExcelDataSet(AbstractDataSet):
     """``AppendableExcelDataSet`` loads/saves data from/to a local Excel file opened in
     append mode. It uses pandas to handle the Excel file.
 
-    Example:
+    Example adding a catalog entry with
+    `YAML API <https://kedro.readthedocs.io/en/stable/05_data/\
+        01_data_catalog.html#using-the-data-catalog-with-the-yaml-api>`_:
+
+    .. code-block:: yaml
+
+        >>> # AppendableExcelDataSet creates a new sheet for every dataset
+        >>> # ExcelDataSet restricts one dataset per file as it is overwritten
+        >>>
+        >>> preprocessed_companies:
+        >>>   type: pandas.AppendableExcelDataSet
+        >>>   filepath: data/02_intermediate/preprocessed.xlsx # assumes file already exists
+        >>>   save_args:
+        >>>     sheet_name: preprocessed_companies
+        >>>   load_args:
+        >>>     sheet_name: preprocessed_companies
+        >>>
+        >>> preprocessed_shuttles:
+        >>>   type: pandas.AppendableExcelDataSet
+        >>>   filepath: data/02_intermediate/preprocessed.xlsx
+        >>>   save_args:
+        >>>     sheet_name: preprocessed_shuttles
+        >>>   load_args:
+        >>>     sheet_name: preprocessed_shuttles
+
+    Example using Python API:
     ::
 
         >>> from kedro.extras.datasets.pandas import AppendableExcelDataSet
