@@ -1,37 +1,9 @@
-# Copyright 2021 QuantumBlack Visual Analytics Limited
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
-# NONINFRINGEMENT. IN NO EVENT WILL THE LICENSOR OR OTHER CONTRIBUTORS
-# BE LIABLE FOR ANY CLAIM, DAMAGES, OR OTHER LIABILITY, WHETHER IN AN
-# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF, OR IN
-# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
-# The QuantumBlack Visual Analytics Limited ("QuantumBlack") name and logo
-# (either separately or in combination, "QuantumBlack Trademarks") are
-# trademarks of QuantumBlack. The License does not grant you any right or
-# license to the QuantumBlack Trademarks. You may not use the QuantumBlack
-# Trademarks or any confusingly similar mark as a trademark for your product,
-# or use the QuantumBlack Trademarks in any other manner that might cause
-# confusion in the marketplace, including but not limited to in advertising,
-# on websites, or on software.
-#
-# See the License for the specific language governing permissions and
-# limitations under the License.
-
 """``PickleDataSet`` loads/saves data from/to a Pickle file using an underlying
 filesystem (e.g.: local, S3, GCS). The underlying functionality is supported by
-the ``pickle``, ``joblib``, and ``compress_pickle`` libraries, so it supports
-all allowed options for loading and saving pickle files.
+the specified backend library passed in (defaults to the ``pickle`` library), so it
+supports all allowed options for loading and saving pickle files.
 """
-import pickle
+import importlib
 from copy import deepcopy
 from pathlib import PurePosixPath
 from typing import Any, Dict
@@ -46,24 +18,35 @@ from kedro.io.core import (
     get_protocol_and_path,
 )
 
-try:
-    import joblib
-except ImportError:  # pragma: no cover
-    joblib = None
-
-try:
-    import compress_pickle
-except ImportError:  # pragma: no cover
-    compress_pickle = None
-
 
 class PickleDataSet(AbstractVersionedDataSet):
     """``PickleDataSet`` loads/saves data from/to a Pickle file using an underlying
     filesystem (e.g.: local, S3, GCS). The underlying functionality is supported by
-    the ``pickle`` and ``joblib`` libraries, so it supports all allowed options for
-    loading and saving pickle files.
+    the specified backend library passed in (defaults to the ``pickle`` library), so it
+    supports all allowed options for loading and saving pickle files.
 
-    Example:
+    Example adding a catalog entry with
+    `YAML API <https://kedro.readthedocs.io/en/stable/05_data/\
+        01_data_catalog.html#using-the-data-catalog-with-the-yaml-api>`_:
+
+    .. code-block:: yaml
+
+        >>> test_model: # simple example without compression
+        >>>   type: pickle.PickleDataSet
+        >>>   filepath: data/07_model_output/test_model.pkl
+        >>>   backend: pickle
+        >>>
+        >>> final_model: # example with load and save args
+        >>>   type: pickle.PickleDataSet
+        >>>   filepath: s3://your_bucket/final_model.pkl.lz4
+        >>>   backend: joblib
+        >>>   credentials: s3_credentials
+        >>>   save_args:
+        >>>     compression: lz4
+        >>>   load_args:
+        >>>     compression: lz4
+
+    Example using Python API:
     ::
 
         >>> from kedro.extras.datasets.pickle import PickleDataSet
@@ -77,7 +60,7 @@ class PickleDataSet(AbstractVersionedDataSet):
         >>> data_set.save(data)
         >>> reloaded = data_set.load()
         >>> assert data.equals(reloaded)
-
+        >>>
         >>> # Add "compress_pickle[lz4]" to requirements.txt
         >>> data_set = PickleDataSet(filepath="test.pickle.lz4",
         >>>                          backend="compress_pickle",
@@ -90,9 +73,8 @@ class PickleDataSet(AbstractVersionedDataSet):
 
     DEFAULT_LOAD_ARGS = {}  # type: Dict[str, Any]
     DEFAULT_SAVE_ARGS = {}  # type: Dict[str, Any]
-    BACKENDS = {"pickle": pickle, "joblib": joblib, "compress_pickle": compress_pickle}
 
-    # pylint: disable=too-many-arguments
+    # pylint: disable=too-many-arguments,too-many-locals
     def __init__(
         self,
         filepath: str,
@@ -104,24 +86,41 @@ class PickleDataSet(AbstractVersionedDataSet):
         fs_args: Dict[str, Any] = None,
     ) -> None:
         """Creates a new instance of ``PickleDataSet`` pointing to a concrete Pickle
-        file on a specific filesystem. ``PickleDataSet`` supports two backends to
-        serialize/deserialize objects: `pickle` and `joblib`.
+        file on a specific filesystem. ``PickleDataSet`` supports custom backends to
+        serialize/deserialize objects.
+
+        Example backends that are compatible (non-exhaustive):
+            * `pickle`
+            * `joblib`
+            * `dill`
+            * `compress_pickle`
+
+        Example backends that are incompatible:
+            * `torch`
 
         Args:
             filepath: Filepath in POSIX format to a Pickle file prefixed with a protocol like
                 `s3://`. If prefix is not provided, `file` protocol (local filesystem) will be used.
                 The prefix should be any protocol supported by ``fsspec``.
                 Note: `http(s)` doesn't support versioning.
-            backend: Backend to use, must be one of ['pickle', 'joblib']. Defaults to 'pickle'.
+            backend: Backend to use, must be an import path to a module which satisfies the
+                ``pickle`` interface. That is, contains a `load` and `dump` function.
+                Defaults to 'pickle'.
             load_args: Pickle options for loading pickle files.
-                Here you can find all available arguments for different backends:
+                You can pass in arguments that the backend load function specified accepts, e.g:
                 pickle.load: https://docs.python.org/3/library/pickle.html#pickle.load
                 joblib.load: https://joblib.readthedocs.io/en/latest/generated/joblib.load.html
+                dill.load: https://dill.readthedocs.io/en/latest/dill.html#dill._dill.load
+                compress_pickle.load:
+                https://lucianopaz.github.io/compress_pickle/html/api/compress_pickle.html#compress_pickle.compress_pickle.load
                 All defaults are preserved.
             save_args: Pickle options for saving pickle files.
-                Here you can find all available arguments for different backends:
+                You can pass in arguments that the backend dump function specified accepts, e.g:
                 pickle.dump: https://docs.python.org/3/library/pickle.html#pickle.dump
                 joblib.dump: https://joblib.readthedocs.io/en/latest/generated/joblib.dump.html
+                dill.dump: https://dill.readthedocs.io/en/latest/dill.html#dill._dill.dump
+                compress_pickle.dump:
+                https://lucianopaz.github.io/compress_pickle/html/api/compress_pickle.html#compress_pickle.compress_pickle.dump
                 All defaults are preserved.
             version: If specified, should be an instance of
                 ``kedro.io.core.Version``. If its ``load`` attribute is
@@ -138,19 +137,23 @@ class PickleDataSet(AbstractVersionedDataSet):
                 All defaults are preserved, except `mode`, which is set to `wb` when saving.
 
         Raises:
-            ValueError: If ``backend`` is not one of ['pickle', 'joblib'].
-            ImportError: If ``backend`` library could not be imported.
+            ValueError: If ``backend`` does not satisfy the `pickle` interface.
+            ImportError: If the ``backend`` module could not be imported.
         """
-        if backend not in self.BACKENDS:
-            raise ValueError(
-                f"'backend' should be one of {list(self.BACKENDS.keys())}, "
-                f"got '{backend}'."
-            )
-
-        if not self.BACKENDS[backend]:
+        try:
+            imported_backend = importlib.import_module(backend)
+        except ImportError as exc:
             raise ImportError(
-                f"Selected backend '{backend}' could not be "
-                "imported. Make sure it is installed."
+                f"Selected backend '{backend}' could not be imported. "
+                "Make sure it is installed and importable."
+            ) from exc
+
+        if not (
+            hasattr(imported_backend, "load") and hasattr(imported_backend, "dump")
+        ):
+            raise ValueError(
+                f"Selected backend '{backend}' should satisfy the pickle interface. "
+                "Missing one of `load` and `dump` on the backend."
             )
 
         _fs_args = deepcopy(fs_args) or {}
@@ -172,7 +175,7 @@ class PickleDataSet(AbstractVersionedDataSet):
             glob_function=self._fs.glob,
         )
 
-        self._backend = backend
+        self._backend = imported_backend
 
         # Handle default load and save arguments
         self._load_args = deepcopy(self.DEFAULT_LOAD_ARGS)
@@ -200,16 +203,14 @@ class PickleDataSet(AbstractVersionedDataSet):
         load_path = get_filepath_str(self._get_load_path(), self._protocol)
 
         with self._fs.open(load_path, **self._fs_open_args_load) as fs_file:
-            return self.BACKENDS[self._backend].load(
-                fs_file, **self._load_args
-            )  # nosec
+            return self._backend.load(fs_file, **self._load_args)  # type: ignore
 
     def _save(self, data: Any) -> None:
         save_path = get_filepath_str(self._get_save_path(), self._protocol)
 
         with self._fs.open(save_path, **self._fs_open_args_save) as fs_file:
             try:
-                self.BACKENDS[self._backend].dump(data, fs_file, **self._save_args)
+                self._backend.dump(data, fs_file, **self._save_args)  # type: ignore
             except Exception as exc:
                 raise DataSetError(
                     f"{data.__class__} was not serialized due to: {exc}"
