@@ -1,32 +1,4 @@
-# Copyright 2021 QuantumBlack Visual Analytics Limited
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
-# NONINFRINGEMENT. IN NO EVENT WILL THE LICENSOR OR OTHER CONTRIBUTORS
-# BE LIABLE FOR ANY CLAIM, DAMAGES, OR OTHER LIABILITY, WHETHER IN AN
-# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF, OR IN
-# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
-# The QuantumBlack Visual Analytics Limited ("QuantumBlack") name and logo
-# (either separately or in combination, "QuantumBlack Trademarks") are
-# trademarks of QuantumBlack. The License does not grant you any right or
-# license to the QuantumBlack Trademarks. You may not use the QuantumBlack
-# Trademarks or any confusingly similar mark as a trademark for your product,
-# or use the QuantumBlack Trademarks in any other manner that might cause
-# confusion in the marketplace, including but not limited to in advertising,
-# on websites, or on software.
-#
-# See the License for the specific language governing permissions and
-# limitations under the License.
-
-"""``AbstractDataSet`` implementation to access Spark dataframes using
+"""``AbstractVersionedDataSet`` implementation to access Spark dataframes using
 ``pyspark``
 """
 from copy import deepcopy
@@ -41,7 +13,7 @@ from pyspark.sql import DataFrame, SparkSession
 from pyspark.sql.utils import AnalysisException
 from s3fs import S3FileSystem
 
-from kedro.io.core import AbstractVersionedDataSet, Version
+from kedro.io.core import AbstractVersionedDataSet, DataSetError, Version
 
 
 def _parse_glob_pattern(pattern: str) -> str:
@@ -164,11 +136,11 @@ class KedroHdfsInsecureClient(InsecureClient):
             for dpath, _, fnames in self.walk(prefix):
                 if fnmatch(dpath, pattern):
                     matched.add(dpath)
-                matched |= set(
+                matched |= {
                     f"{dpath}/{fname}"
                     for fname in fnames
                     if fnmatch(f"{dpath}/{fname}", pattern)
-                )
+                }
         except HdfsError:  # pragma: no cover
             # HdfsError is raised by `self.walk()` if prefix does not exist in HDFS.
             # Ignore and return an empty list.
@@ -179,7 +151,29 @@ class KedroHdfsInsecureClient(InsecureClient):
 class SparkDataSet(AbstractVersionedDataSet):
     """``SparkDataSet`` loads and saves Spark dataframes.
 
-    Example:
+    Example adding a catalog entry with
+    `YAML API <https://kedro.readthedocs.io/en/stable/05_data/\
+        01_data_catalog.html#using-the-data-catalog-with-the-yaml-api>`_:
+
+    .. code-block:: yaml
+
+        >>> weather:
+        >>>   type: spark.SparkDataSet
+        >>>   filepath: s3a://your_bucket/data/01_raw/weather/*
+        >>>   file_format: csv
+        >>>   load_args:
+        >>>     header: True
+        >>>     inferSchema: True
+        >>>   save_args:
+        >>>     sep: '|'
+        >>>     header: True
+        >>>
+        >>> weather_cleaned:
+        >>>   type: spark.SparkDataSet
+        >>>   filepath: data/02_intermediate/data.parquet
+        >>>   file_format: parquet
+
+    Example using Python API:
     ::
 
         >>> from pyspark.sql import SparkSession
@@ -203,6 +197,10 @@ class SparkDataSet(AbstractVersionedDataSet):
         >>> reloaded.take(4)
     """
 
+    # this dataset cannot be used with ``ParallelRunner``,
+    # therefore it has the attribute ``_SINGLE_PROCESS = True``
+    # for parallelism within a Spark pipeline please consider
+    # ``ThreadRunner`` instead
     _SINGLE_PROCESS = True
     DEFAULT_LOAD_ARGS = {}  # type: Dict[str, Any]
     DEFAULT_SAVE_ARGS = {}  # type: Dict[str, Any]
@@ -225,7 +223,7 @@ class SparkDataSet(AbstractVersionedDataSet):
                 starting with ``/dbfs/mnt``.
             file_format: File format used during load and save
                 operations. These are formats supported by the running
-                SparkContext include parquet, csv. For a list of supported
+                SparkContext include parquet, csv, delta. For a list of supported
                 formats please refer to Apache Spark documentation at
                 https://spark.apache.org/docs/latest/sql-programming-guide.html
             load_args: Load args passed to Spark DataFrameReader load method.
@@ -268,10 +266,9 @@ class SparkDataSet(AbstractVersionedDataSet):
 
         elif fs_prefix == "hdfs://" and version:
             warn(
-                "HDFS filesystem support for versioned {} is in beta and uses "
-                "`hdfs.client.InsecureClient`, please use with caution".format(
-                    self.__class__.__name__
-                )
+                f"HDFS filesystem support for versioned {self.__class__.__name__} is "
+                f"in beta and uses `hdfs.client.InsecureClient`, please use with "
+                f"caution"
             )
 
             # default namenode address
@@ -310,6 +307,8 @@ class SparkDataSet(AbstractVersionedDataSet):
         self._file_format = file_format
         self._fs_prefix = fs_prefix
 
+        self._handle_delta_format()
+
     def _describe(self) -> Dict[str, Any]:
         return dict(
             filepath=self._fs_prefix + str(self._filepath),
@@ -340,7 +339,24 @@ class SparkDataSet(AbstractVersionedDataSet):
         try:
             self._get_spark().read.load(load_path, self._file_format)
         except AnalysisException as exception:
-            if exception.desc.startswith("Path does not exist:"):
+            if (
+                exception.desc.startswith("Path does not exist:")
+                or "is not a Delta table" in exception.desc
+            ):
                 return False
             raise
         return True
+
+    def _handle_delta_format(self) -> None:
+        supported_modes = {"append", "overwrite", "error", "errorifexists", "ignore"}
+        write_mode = self._save_args.get("mode")
+        if (
+            write_mode
+            and self._file_format == "delta"
+            and write_mode not in supported_modes
+        ):
+            raise DataSetError(
+                f"It is not possible to perform `save()` for file format `delta` "
+                f"with mode `{write_mode}` on `SparkDataSet`. "
+                f"Please use `spark.DeltaTableDataSet` instead."
+            )
