@@ -1,30 +1,4 @@
-# Copyright 2021 QuantumBlack Visual Analytics Limited
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
-# NONINFRINGEMENT. IN NO EVENT WILL THE LICENSOR OR OTHER CONTRIBUTORS
-# BE LIABLE FOR ANY CLAIM, DAMAGES, OR OTHER LIABILITY, WHETHER IN AN
-# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF, OR IN
-# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
-# The QuantumBlack Visual Analytics Limited ("QuantumBlack") name and logo
-# (either separately or in combination, "QuantumBlack Trademarks") are
-# trademarks of QuantumBlack. The License does not grant you any right or
-# license to the QuantumBlack Trademarks. You may not use the QuantumBlack
-# Trademarks or any confusingly similar mark as a trademark for your product,
-# or use the QuantumBlack Trademarks in any other manner that might cause
-# confusion in the marketplace, including but not limited to in advertising,
-# on websites, or on software.
-#
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# pylint: disable=too-many-lines
 
 """A collection of CLI commands for working with Kedro pipelines."""
 import json
@@ -35,11 +9,16 @@ import tempfile
 from importlib import import_module
 from pathlib import Path
 from textwrap import indent
-from typing import Any, List, NamedTuple, Optional, Tuple, Union
+from typing import Any, Iterable, List, NamedTuple, Optional, Set, Tuple, Union
 from zipfile import ZipFile
 
 import click
+import pkg_resources
 import yaml
+from rope.base.project import Project
+from rope.contrib import generate
+from rope.refactor.move import MoveModule
+from rope.refactor.rename import Rename
 from setuptools.dist import Distribution
 
 import kedro
@@ -47,6 +26,7 @@ from kedro.framework.cli.utils import (
     KedroCliError,
     _clean_pycache,
     _filter_deprecation_warnings,
+    _get_requirements_in,
     call,
     command_with_verbosity,
     env_option,
@@ -65,13 +45,17 @@ setup(
     packages=find_packages(),
     include_package_data=True,
     package_data={package_data},
+    install_requires={install_requires},
 )
 """
 
-PipelineArtifacts = NamedTuple(
-    "PipelineArtifacts",
-    [("pipeline_dir", Path), ("pipeline_tests", Path), ("pipeline_conf", Path)],
-)
+
+class PipelineArtifacts(NamedTuple):
+    """An ordered collection of source_path, tests_path, config_paths"""
+
+    pipeline_dir: Path
+    pipeline_tests: Path
+    pipeline_conf: Path
 
 
 def _assert_pkg_name_ok(pkg_name: str):
@@ -104,6 +88,13 @@ def _check_pipeline_name(ctx, param, value):  # pylint: disable=unused-argument
     return value
 
 
+def _check_module_path(ctx, param, value):  # pylint: disable=unused-argument
+    if value and not re.match(r"^[\w.]+$", value):
+        message = "The pipeline location you provided is not a valid Python module path"
+        raise KedroCliError(message)
+    return value
+
+
 # pylint: disable=missing-function-docstring
 @click.group(name="Kedro")
 def pipeline_cli():  # pragma: no cover
@@ -215,7 +206,13 @@ def delete_pipeline(
 
 @pipeline.command("list")
 def list_pipelines():
-    """List all pipelines defined in your pipeline_registry.py file."""
+    """List all pipelines defined in your pipeline_registry.py file. (DEPRECATED)"""
+    deprecation_message = (
+        "DeprecationWarning: Command `kedro pipeline list` is deprecated. "
+        "Please use `kedro registry list` instead."
+    )
+    click.secho(deprecation_message, fg="red")
+
     click.echo(yaml.dump(sorted(pipelines)))
 
 
@@ -225,7 +222,15 @@ def list_pipelines():
 def describe_pipeline(
     metadata: ProjectMetadata, name, **kwargs
 ):  # pylint: disable=unused-argument, protected-access
-    """Describe a pipeline by providing a pipeline name. Defaults to the __default__ pipeline."""
+    """Describe a pipeline by providing a pipeline name.
+    Defaults to the __default__ pipeline. (DEPRECATED)
+    """
+    deprecation_message = (
+        "DeprecationWarning: Command `kedro pipeline describe` is deprecated. "
+        "Please use `kedro registry describe` instead."
+    )
+    click.secho(deprecation_message, fg="red")
+
     pipeline_obj = pipelines.get(name)
     if not pipeline_obj:
         all_pipeline_names = pipelines.keys()
@@ -244,7 +249,14 @@ def describe_pipeline(
 
 
 @command_with_verbosity(pipeline, "pull")
-@click.argument("package_path", nargs=1)
+@click.argument("package_path", nargs=1, required=False)
+@click.option(
+    "--all",
+    "-a",
+    "all_flag",
+    is_flag=True,
+    help="Pull and unpack all pipelines in the `pyproject.toml` package manifest section.",
+)
 @env_option(
     help="Environment to install the pipeline configuration to. Defaults to `base`."
 )
@@ -264,11 +276,34 @@ def describe_pipeline(
     help="Location of a configuration file for the fsspec filesystem used to pull the package.",
 )
 @click.pass_obj  # this will pass the metadata as first argument
-def pull_package(
-    metadata: ProjectMetadata, package_path, env, alias, fs_args, **kwargs
-):  # pylint:disable=unused-argument
+def pull_package(  # pylint:disable=unused-argument, too-many-arguments
+    metadata: ProjectMetadata, package_path, env, alias, fs_args, all_flag, **kwargs
+) -> None:
     """Pull and unpack a modular pipeline in your project."""
+    if not package_path and not all_flag:
+        click.secho(
+            "Please specify a package path or add '--all' to pull all pipelines in the "
+            "`pyproject.toml` package manifest section."
+        )
+        sys.exit(1)
 
+    if all_flag:
+        _pull_packages_from_manifest(metadata)
+        return
+
+    _pull_package(package_path, metadata, env=env, alias=alias, fs_args=fs_args)
+    as_alias = f" as `{alias}`" if alias else ""
+    message = f"Pipeline {package_path} pulled and unpacked{as_alias}!"
+    click.secho(message, fg="green")
+
+
+def _pull_package(
+    package_path: str,
+    metadata: ProjectMetadata,
+    env: str = None,
+    alias: str = None,
+    fs_args: str = None,
+):
     with tempfile.TemporaryDirectory() as temp_dir:
         temp_dir_path = Path(temp_dir).resolve()
 
@@ -283,11 +318,68 @@ def pull_package(
         # Extract package name, based on the naming convention for wheel files
         # https://www.python.org/dev/peps/pep-0427/#file-name-convention
         package_name = dist_info_file[0].stem.split("-")[0]
+        package_metadata = dist_info_file[0] / "METADATA"
+
+        req_pattern = r"Requires-Dist: (.*?)\n"
+        package_reqs = re.findall(req_pattern, package_metadata.read_text())
+        if package_reqs:
+            requirements_in = _get_requirements_in(
+                metadata.source_dir, create_empty=True
+            )
+            _append_package_reqs(requirements_in, package_reqs, package_name)
 
         _clean_pycache(temp_dir_path)
         _install_files(metadata, package_name, temp_dir_path, env, alias)
 
 
+def _pull_packages_from_manifest(metadata: ProjectMetadata) -> None:
+    # pylint: disable=import-outside-toplevel
+    import anyconfig  # for performance reasons
+
+    config_dict = anyconfig.load(metadata.config_file)
+    config_dict = config_dict["tool"]["kedro"]
+    build_specs = config_dict.get("pipeline", {}).get("pull")
+
+    if not build_specs:
+        click.secho(
+            "Nothing to pull. Please update the `pyproject.toml` package manifest section.",
+            fg="yellow",
+        )
+        return
+
+    for package_path, specs in build_specs.items():
+        if "alias" in specs:
+            _assert_pkg_name_ok(specs["alias"])
+        _pull_package(package_path, metadata, **specs)
+        click.secho(f"Pulled and unpacked `{package_path}`!")
+
+    click.secho("Pipelines pulled and unpacked!", fg="green")
+
+
+def _package_pipelines_from_manifest(metadata: ProjectMetadata) -> None:
+    # pylint: disable=import-outside-toplevel
+    import anyconfig  # for performance reasons
+
+    config_dict = anyconfig.load(metadata.config_file)
+    config_dict = config_dict["tool"]["kedro"]
+    build_specs = config_dict.get("pipeline", {}).get("package")
+
+    if not build_specs:
+        click.secho(
+            "Nothing to package. Please update the `pyproject.toml` package manifest section.",
+            fg="yellow",
+        )
+        return
+
+    for pipeline_name, specs in build_specs.items():
+        if "alias" in specs:
+            _assert_pkg_name_ok(specs["alias"])
+        _package_pipeline(pipeline_name, metadata, **specs)
+        click.secho(f"Packaged `{pipeline_name}` pipeline!")
+
+    click.secho("Pipelines packaged!", fg="green")
+
+
 @pipeline.command("package")
 @env_option(
     help="Environment where the pipeline configuration lives. Defaults to `base`."
@@ -313,12 +405,30 @@ def pull_package(
     "Defaults to pipeline package version or, "
     "if that is not defined, the project package version.",
 )
-@click.argument("name", nargs=1)
+@click.option(
+    "--all",
+    "-a",
+    "all_flag",
+    is_flag=True,
+    help="Package all pipelines in the `pyproject.toml` package manifest section.",
+)
+@click.argument("name", nargs=1, required=False, callback=_check_module_path)
 @click.pass_obj  # this will pass the metadata as first argument
 def package_pipeline(
-    metadata: ProjectMetadata, name, env, alias, destination, version
+    metadata: ProjectMetadata, name, env, alias, destination, version, all_flag
 ):  # pylint: disable=too-many-arguments
     """Package up a modular pipeline as a Python .whl."""
+    if not name and not all_flag:
+        click.secho(
+            "Please specify a pipeline name or add '--all' to package all pipelines in "
+            "the `pyproject.toml` package manifest section."
+        )
+        sys.exit(1)
+
+    if all_flag:
+        _package_pipelines_from_manifest(metadata)
+        return
+
     result_path = _package_pipeline(
         name, metadata, alias=alias, destination=destination, env=env, version=version
     )
@@ -365,6 +475,7 @@ def _unpack_wheel(location: str, destination: Path, fs_args: Optional[str]) -> N
 
     if location.endswith(".whl") and filesystem and filesystem.exists(location):
         with filesystem.open(location) as fs_file:
+            # pylint: disable=consider-using-with
             ZipFile(fs_file).extractall(destination)
     else:
         python_call(
@@ -379,6 +490,7 @@ def _unpack_wheel(location: str, destination: Path, fs_args: Optional[str]) -> N
                 f"More than 1 or no wheel files found: {file_names}. "
                 f"There has to be exactly one distribution file."
             )
+        # pylint: disable=consider-using-with
         ZipFile(wheel_file[0]).extractall(destination)
 
 
@@ -393,6 +505,78 @@ def _rename_files(conf_source: Path, old_name: str, new_name: str):
         config_file.rename(config_file.parent / new_config_name)
 
 
+def _refactor_code_for_unpacking(
+    project: Project,
+    package_path: Path,
+    tests_path: Path,
+    alias: Optional[str],
+    project_metadata: ProjectMetadata,
+) -> Tuple[Path, Path]:
+    """This is the reverse operation of `_refactor_code_for_package`, i.e
+    we go from:
+    <temp_dir>  # also the root of the Rope project
+    |__ <pipeline_name>  # or <alias>
+        |__ __init__.py
+    |__ tests  # only tests for <pipeline_name>
+        |__ __init__.py
+        |__ test_pipeline.py
+
+    to:
+    <temp_dir>  # also the root of the Rope project
+    |__ <package>
+        |__ __init__.py
+        |__ pipelines
+            |__ __init__.py
+            |__ <pipeline_name>
+                |__ __init__.py
+    |__ tests
+        |__ __init__.py
+        |__ pipelines
+            |__ __init__.py
+            |__ <pipeline_name>
+                |__ __init__.py
+    """
+
+    def _move_package_with_conflicting_name(
+        target: Path, original_name: str, desired_name: str = None
+    ) -> Path:
+        _rename_package(project, original_name, "tmp_name")
+        full_path = _create_nested_package(project, target)
+        _move_package(project, "tmp_name", target.as_posix())
+        desired_name = desired_name or original_name
+        _rename_package(project, (target / "tmp_name").as_posix(), desired_name)
+        return full_path
+
+    pipeline_name = package_path.stem
+    if alias:
+        _rename_package(project, pipeline_name, alias)
+        pipeline_name = alias
+
+    package_target = Path(project_metadata.package_name) / "pipelines"
+    if pipeline_name == project_metadata.package_name:
+        full_path = _move_package_with_conflicting_name(package_target, pipeline_name)
+    else:
+        full_path = _create_nested_package(project, package_target)
+        _move_package(project, pipeline_name, package_target.as_posix())
+    refactored_package_path = full_path / pipeline_name
+
+    if not tests_path.exists():
+        return refactored_package_path, tests_path
+
+    # we can't rename the tests package to <pipeline_name>
+    # because it will conflict with existing top-level package;
+    # hence we give it a temp name, create the expected
+    # nested folder structure, move the contents there,
+    # then rename the temp name to <pipeline_name>.
+    tests_target = Path("tests") / "pipelines"
+    full_path = _move_package_with_conflicting_name(
+        tests_target, original_name="tests", desired_name=pipeline_name
+    )
+    refactored_tests_path = full_path / pipeline_name
+
+    return refactored_package_path, refactored_tests_path
+
+
 def _install_files(
     project_metadata: ProjectMetadata,
     package_name: str,
@@ -421,13 +605,19 @@ def _install_files(
         # we don't want to copy it again when syncing the package, so we remove it.
         shutil.rmtree(str(conf_source))
 
-    if test_source.is_dir():
-        _sync_dirs(test_source, test_dest)
+    project = Project(source_path)
+    refactored_package_source, refactored_test_source = _refactor_code_for_unpacking(
+        project, package_source, test_source, alias, project_metadata
+    )
+    project.close()
+
+    if refactored_test_source.is_dir():
+        _sync_dirs(refactored_test_source, test_dest)
 
     # Sync everything under package directory, except `config`
     # since it has already been copied.
-    if package_source.is_dir():
-        _sync_dirs(package_source, package_dest)
+    if refactored_package_source.is_dir():
+        _sync_dirs(refactored_package_source, package_dest)
 
 
 def _find_config_files(
@@ -446,6 +636,19 @@ def _find_config_files(
     return config_files
 
 
+def _get_default_version(metadata: ProjectMetadata, pipeline_name: str) -> str:
+    # default to pipeline package version
+    try:
+        pipeline_module = import_module(
+            f"{metadata.package_name}.pipelines.{pipeline_name}"
+        )
+        return pipeline_module.__version__  # type: ignore
+    except (AttributeError, ModuleNotFoundError):
+        # if pipeline version doesn't exist, take the project one
+        project_module = import_module(f"{metadata.package_name}")
+        return project_module.__version__  # type: ignore
+
+
 def _package_pipeline(  # pylint: disable=too-many-arguments
     pipeline_name: str,
     metadata: ProjectMetadata,
@@ -464,8 +667,9 @@ def _package_pipeline(  # pylint: disable=too-many-arguments
     # config files not to confuse users and avoid useless file copies
     configs_to_package = _find_config_files(
         artifacts_to_package.pipeline_conf,
-        [f"parameters*/**/{pipeline_name}.yml", f"parameters*/**/{pipeline_name}/*"],
+        [f"parameters*/**/{pipeline_name}.yml", f"parameters*/**/{pipeline_name}/**/*"],
     )
+
     source_paths = (
         artifacts_to_package.pipeline_dir,
         artifacts_to_package.pipeline_tests,
@@ -474,21 +678,17 @@ def _package_pipeline(  # pylint: disable=too-many-arguments
 
     # Check that pipeline directory exists and not empty
     _validate_dir(artifacts_to_package.pipeline_dir)
+
     destination = Path(destination) if destination else package_dir.parent / "dist"
+    version = version or _get_default_version(metadata, pipeline_name)
 
-    if not version:  # default to pipeline package version
-        try:
-            pipeline_module = import_module(
-                f"{metadata.package_name}.pipelines.{pipeline_name}"
-            )
-            version = pipeline_module.__version__  # type: ignore
-        except (AttributeError, ModuleNotFoundError):
-            # if pipeline version doesn't exist, take the project one
-            project_module = import_module(f"{metadata.package_name}")
-            version = project_module.__version__  # type: ignore
-
-    _generate_wheel_file(  # type: ignore
-        pipeline_name, destination, source_paths, version, alias=alias
+    _generate_wheel_file(
+        pipeline_name=pipeline_name,
+        destination=destination.resolve(),
+        source_paths=source_paths,
+        version=version,
+        metadata=metadata,
+        alias=alias,
     )
 
     _clean_pycache(package_dir)
@@ -521,33 +721,190 @@ def _sync_path_list(source: List[Tuple[Path, str]], target: Path) -> None:
         _sync_dirs(source_path, target_with_suffix)
 
 
+def _make_install_requires(requirements_txt: Path) -> List[str]:
+    """Parses each line of requirements.txt into a version specifier valid to put in
+    install_requires."""
+    if not requirements_txt.exists():
+        return []
+    requirements = pkg_resources.parse_requirements(requirements_txt.read_text())
+    return [str(requirement) for requirement in requirements]
+
+
+def _create_nested_package(project: Project, package_path: Path) -> Path:
+    # fails if parts of the path exists already
+    packages = package_path.parts
+    parent = generate.create_package(project, packages[0])
+    nested_path = Path(project.address) / packages[0]
+    for package in packages[1:]:
+        parent = generate.create_package(project, package, sourcefolder=parent)
+        nested_path = nested_path / package
+    return nested_path
+
+
+def _move_package(project: Project, source: str, target: str) -> None:
+    """
+    Move a Python package, refactoring relevant imports along the way.
+    A target of empty string means moving to the root of the `project`.
+
+    Args:
+        project: rope.base.Project holding the scope of the refactoring.
+        source: Name of the Python package to be moved. Can be a fully
+            qualified module path relative to the `project` root, e.g.
+            "package.pipelines.pipeline" or "package/pipelines/pipeline".
+        target: Destination of the Python package to be moved. Can be a fully
+            qualified module path relative to the `project` root, e.g.
+            "package.pipelines.pipeline" or "package/pipelines/pipeline".
+    """
+    src_folder = project.get_module(source).get_resource()
+    target_folder = project.get_module(target).get_resource()
+    change = MoveModule(project, src_folder).get_changes(dest=target_folder)
+    project.do(change)
+
+
+def _rename_package(project: Project, old_name: str, new_name: str) -> None:
+    """
+    Rename a Python package, refactoring relevant imports along the way,
+    as well as references in comments.
+
+    Args:
+        project: rope.base.Project holding the scope of the refactoring.
+        old_name: Old module name. Can be a fully qualified module path,
+            e.g. "package.pipelines.pipeline" or "package/pipelines/pipeline",
+            relative to the `project` root.
+        new_name: New module name. Can't be a fully qualified module path.
+    """
+    folder = project.get_folder(old_name)
+    change = Rename(project, folder).get_changes(new_name, docs=True)
+    project.do(change)
+
+
+def _refactor_code_for_package(
+    project: Project,
+    package_path: Path,
+    tests_path: Path,
+    alias: Optional[str],
+    project_metadata: ProjectMetadata,
+) -> None:
+    """In order to refactor the imports properly, we need to recreate
+    the same nested structure as in the project. Therefore, we create:
+    <temp_dir>  # also the root of the Rope project
+    |__ <package>
+        |__ __init__.py
+        |__ pipelines
+            |__ __init__.py
+            |__ <pipeline_name>
+                |__ __init__.py
+    |__ tests
+        |__ __init__.py
+        |__ pipelines
+            |__ __init__.py
+            |__ <pipeline_name>
+                |__ __init__.py
+    We then move <pipeline_name> outside of package src to top level ("")
+    in temp_dir, and rename folder & imports if alias provided.
+
+    For tests, we need to extract all the contents of <pipeline_name>
+    at into top-level `tests` folder. This is not possible in one go with
+    the Rope API, so we have to do it in a bit of a hacky way.
+    We rename <pipeline_name> to a `tmp_name` and move it at top-level ("")
+    in temp_dir. We remove the old `tests` folder and rename `tmp_name` to `tests`.
+
+    The final structure should be:
+    <temp_dir>  # also the root of the Rope project
+    |__ <pipeline_name>  # or <alias>
+        |__ __init__.py
+    |__ tests  # only tests for <pipeline_name>
+        |__ __init__.py
+        |__ test_pipeline.py
+    """
+
+    def _move_package_with_conflicting_name(target: Path, conflicting_name: str):
+        tmp_name = "tmp_name"
+        tmp_module = target.parent / tmp_name
+        _rename_package(project, target.as_posix(), tmp_name)
+        _move_package(project, tmp_module.as_posix(), "")
+        shutil.rmtree(Path(project.address) / conflicting_name)
+        _rename_package(project, tmp_name, conflicting_name)
+
+    # Copy source in appropriate folder structure
+    package_target = package_path.relative_to(project_metadata.source_dir)
+    full_path = _create_nested_package(project, package_target)
+    # overwrite=True to update the __init__.py files generated by create_package
+    _sync_dirs(package_path, full_path, overwrite=True)
+
+    # Copy tests in appropriate folder structure
+    if tests_path.exists():
+        tests_target = tests_path.relative_to(project_metadata.source_dir)
+        full_path = _create_nested_package(project, tests_target)
+        # overwrite=True to update the __init__.py files generated by create_package
+        _sync_dirs(tests_path, full_path, overwrite=True)
+
+    # Refactor imports in src/package_name/pipelines/pipeline_name
+    # and imports of `pipeline_name` in tests.
+    pipeline_name = package_target.stem
+    if pipeline_name == project_metadata.package_name:
+        _move_package_with_conflicting_name(package_target, pipeline_name)
+    else:
+        _move_package(project, package_target.as_posix(), "")
+        shutil.rmtree(Path(project.address) / project_metadata.package_name)
+
+    if alias:
+        _rename_package(project, pipeline_name, alias)
+
+    if tests_path.exists():
+        # we can't move the relevant tests folder as is because
+        # it will conflict with the top-level package <pipeline_name>;
+        # we can't rename it "tests" and move it, because it will conflict
+        # with the existing "tests" folder at top level;
+        # hence we give it a temp name, move it, delete tests/ and
+        # rename the temp name to tests.
+        _move_package_with_conflicting_name(tests_target, "tests")
+
+
 _SourcePathType = Union[Path, List[Tuple[Path, str]]]
 
 
+# pylint: disable=too-many-arguments,too-many-locals
 def _generate_wheel_file(
     pipeline_name: str,
     destination: Path,
     source_paths: Tuple[_SourcePathType, ...],
     version: str,
+    metadata: ProjectMetadata,
     alias: str = None,
 ) -> None:
     package_name = alias or pipeline_name
+    package_source, tests_source, conf_source = source_paths
 
     with tempfile.TemporaryDirectory() as temp_dir:
         temp_dir_path = Path(temp_dir).resolve()
 
-        # Copy source folders
-        target_paths = _get_package_artifacts(temp_dir_path, package_name)
-        for source, target in zip(source_paths, target_paths):
-            sync_func = _sync_path_list if isinstance(source, list) else _sync_dirs
-            sync_func(source, target)  # type: ignore
+        project = Project(temp_dir_path)  # project where to do refactoring
+        _refactor_code_for_package(  # type: ignore
+            project, package_source, tests_source, alias, metadata
+        )
+        project.close()
 
-        conf_target = target_paths[-1]
+        # Copy & "refactor" config
+        _, _, conf_target = _get_package_artifacts(temp_dir_path, package_name)
+        _sync_path_list(conf_source, conf_target)  # type: ignore
         if conf_target.is_dir() and alias:
             _rename_files(conf_target, pipeline_name, alias)
 
         # Build a setup.py on the fly
-        setup_file = _generate_setup_file(package_name, version, temp_dir_path)
+        try:
+            install_requires = _make_install_requires(
+                package_source / "requirements.txt"  # type: ignore
+            )
+        except Exception as exc:
+            click.secho("FAILED", fg="red")
+            cls = exc.__class__
+            raise KedroCliError(f"{cls.__module__}.{cls.__qualname__}: {exc}") from exc
+
+        config_files = [str(file) for file in conf_target.rglob("*") if file.is_file()]
+        setup_file = _generate_setup_file(
+            package_name, version, install_requires, temp_dir_path, config_files
+        )
 
         package_file = destination / _get_wheel_name(name=package_name, version=version)
         if package_file.is_file():
@@ -568,20 +925,23 @@ def _generate_wheel_file(
         )
 
 
-def _generate_setup_file(package_name: str, version: str, output_dir: Path) -> Path:
+def _generate_setup_file(
+    package_name: str,
+    version: str,
+    install_requires: List[str],
+    output_dir: Path,
+    config_files: List[str],
+) -> Path:
     setup_file = output_dir / "setup.py"
-    package_data = {
-        package_name: [
-            "README.md",
-            "config/parameters*",
-            "config/**/parameters*",
-            "config/parameters*/**",
-            "config/parameters*/**/*",
-        ]
-    }
+
+    package_data = {package_name: ["README.md"] + config_files}
     setup_file_context = dict(
-        name=package_name, version=version, package_data=json.dumps(package_data)
+        name=package_name,
+        version=version,
+        package_data=json.dumps(package_data),
+        install_requires=install_requires,
     )
+
     setup_file.write_text(_SETUP_PY_TEMPLATE.format(**setup_file_context))
     return setup_file
 
@@ -619,11 +979,12 @@ def _create_pipeline(name: str, output_dir: Path) -> Path:
 
 
 # pylint: disable=missing-raises-doc
-def _sync_dirs(source: Path, target: Path, prefix: str = ""):
+def _sync_dirs(source: Path, target: Path, prefix: str = "", overwrite: bool = False):
     """Recursively copies `source` directory (or file) into `target` directory without
     overwriting any existing files/directories in the target using the following
     rules:
-        1) Skip any files/directories which names match with files in target.
+        1) Skip any files/directories which names match with files in target,
+        unless overwrite=True.
         2) Copy all files from source to target.
         3) Recursively copy all directories from source to target.
 
@@ -642,7 +1003,8 @@ def _sync_dirs(source: Path, target: Path, prefix: str = ""):
     elif source.is_file():
         content = [source]
     else:
-        content = []  # nothing to copy
+        # nothing to copy
+        content = []  # pragma: no cover
 
     for source_path in content:
         source_name = source_path.name
@@ -650,7 +1012,8 @@ def _sync_dirs(source: Path, target: Path, prefix: str = ""):
         click.echo(indent(f"Creating `{target_path}`: ", prefix), nl=False)
 
         if (  # rule #1
-            source_name in existing_files
+            not overwrite
+            and source_name in existing_files
             or source_path.is_file()
             and source_name in existing_folders
         ):
@@ -734,3 +1097,48 @@ def _delete_artifacts(*artifacts: Path):
             raise KedroCliError(f"{cls.__module__}.{cls.__qualname__}: {exc}") from exc
         else:
             click.secho("OK", fg="green")
+
+
+def _append_package_reqs(
+    requirements_in: Path, package_reqs: List[str], pipeline_name: str
+) -> None:
+    """Appends modular pipeline requirements to project level requirements.in"""
+    existing_reqs = _safe_parse_requirements(requirements_in.read_text())
+    incoming_reqs = _safe_parse_requirements(package_reqs)
+    reqs_to_add = set(incoming_reqs) - set(existing_reqs)
+    if not reqs_to_add:
+        return
+
+    sorted_reqs = sorted(str(req) for req in reqs_to_add)
+    sep = "\n"
+    with open(requirements_in, "a", encoding="utf-8") as file:
+        file.write(
+            f"\n\n# Additional requirements from modular pipeline `{pipeline_name}`:\n"
+        )
+        file.write(sep.join(sorted_reqs))
+    click.secho(
+        f"Added the following requirements from modular pipeline `{pipeline_name}` to "
+        f"requirements.in:\n{sep.join(sorted_reqs)}"
+    )
+    click.secho(
+        "Use `kedro install --build-reqs` to compile and install the updated list of "
+        "requirements."
+    )
+
+
+def _safe_parse_requirements(
+    requirements: Union[str, Iterable[str]]
+) -> Set[pkg_resources.Requirement]:
+    """Safely parse a requirement or set of requirements. This effectively replaces
+    pkg_resources.parse_requirements, which blows up with a ValueError as soon as it
+    encounters a requirement it cannot parse (e.g. `-r requirements.txt`). This way
+    we can still extract all the parseable requirements out of a set containing some
+    unparseable requirements.
+    """
+    parseable_requirements = set()
+    for requirement in pkg_resources.yield_lines(requirements):
+        try:
+            parseable_requirements.add(pkg_resources.Requirement.parse(requirement))
+        except ValueError:
+            continue
+    return parseable_requirements
