@@ -1,32 +1,3 @@
-# Copyright 2021 QuantumBlack Visual Analytics Limited
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
-# NONINFRINGEMENT. IN NO EVENT WILL THE LICENSOR OR OTHER CONTRIBUTORS
-# BE LIABLE FOR ANY CLAIM, DAMAGES, OR OTHER LIABILITY, WHETHER IN AN
-# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF, OR IN
-# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
-# The QuantumBlack Visual Analytics Limited ("QuantumBlack") name and logo
-# (either separately or in combination, "QuantumBlack Trademarks") are
-# trademarks of QuantumBlack. The License does not grant you any right or
-# license to the QuantumBlack Trademarks. You may not use the QuantumBlack
-# Trademarks or any confusingly similar mark as a trademark for your product,
-# or use the QuantumBlack Trademarks in any other manner that might cause
-# confusion in the marketplace, including but not limited to in advertising,
-# on websites, or on software.
-#
-# See the License for the specific language governing permissions and
-# limitations under the License.
-
-
 """kedro is a CLI for managing Kedro projects.
 
 This module implements commands available from the kedro CLI for creating
@@ -42,7 +13,6 @@ from pathlib import Path
 from typing import Any, Callable, Dict, List, Optional, Tuple
 
 import click
-import git
 import yaml
 
 import kedro
@@ -59,7 +29,7 @@ KEDRO_PATH = Path(kedro.__file__).parent
 TEMPLATE_PATH = KEDRO_PATH / "templates" / "project"
 
 _STARTER_ALIASES = {
-    "astro-iris",
+    "astro-airflow-iris",
     "mini-kedro",
     "pandas-iris",
     "pyspark",
@@ -152,7 +122,9 @@ def new(
 
     # Obtain config, either from a file or from interactive user prompts.
     if not prompts_required:
-        config = dict()
+        config = {}
+        if config_path:
+            config = _fetch_config_from_file(config_path)
     elif config_path:
         config = _fetch_config_from_file(config_path)
         _validate_config_file(config, prompts_required)
@@ -171,9 +143,7 @@ def starter():
 @starter.command("list")
 def list_starters():
     """List all official project starters available."""
-    repo_url = _STARTERS_REPO.replace("git+", "").replace(
-        ".git", "/tree/master/{alias}"
-    )
+    repo_url = _STARTERS_REPO.replace("git+", "").replace(".git", "/tree/main/{alias}")
     output = [
         {alias: repo_url.format(alias=alias)} for alias in sorted(_STARTER_ALIASES)
     ]
@@ -196,7 +166,7 @@ def _fetch_config_from_file(config_path: str) -> Dict[str, str]:
 
     """
     try:
-        with open(config_path, "r") as config_file:
+        with open(config_path, encoding="utf-8") as config_file:
             config = yaml.safe_load(config_file)
 
         if KedroCliError.VERBOSE_ERROR:
@@ -298,7 +268,7 @@ def _get_cookiecutter_dir(
     try:
         cookiecutter_dir, _ = determine_repo_dir(
             template=template_path,
-            abbreviations=dict(),
+            abbreviations={},
             clone_to_dir=Path(tmpdir).resolve(),
             checkout=checkout,
             no_input=True,
@@ -349,7 +319,7 @@ def _fetch_config_from_user_prompts(
     from cookiecutter.environment import StrictEnvironment
     from cookiecutter.prompt import read_user_variable, render_variable
 
-    config: Dict[str, str] = dict()
+    config: Dict[str, str] = {}
 
     for variable_name, prompt_dict in prompts.items():
         prompt = _Prompt(**prompt_dict)
@@ -408,6 +378,10 @@ class _Prompt:
 
 
 def _get_available_tags(template_path: str) -> List:
+    # Not at top level so that kedro CLI works without a working git executable.
+    # pylint: disable=import-outside-toplevel
+    import git
+
     try:
         tags = git.cmd.Git().ls_remote("--tags", template_path.replace("git+", ""))
 
@@ -436,7 +410,6 @@ def _validate_config_file(config: Dict[str, str], prompts: Dict[str, Any]):
     """
     if config is None:
         raise KedroCliError("Config file is empty.")
-
     missing_keys = set(prompts) - set(config)
     if missing_keys:
         click.echo(yaml.dump(config, default_flow_style=False))
