@@ -1,31 +1,3 @@
-# Copyright 2021 QuantumBlack Visual Analytics Limited
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
-# NONINFRINGEMENT. IN NO EVENT WILL THE LICENSOR OR OTHER CONTRIBUTORS
-# BE LIABLE FOR ANY CLAIM, DAMAGES, OR OTHER LIABILITY, WHETHER IN AN
-# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF, OR IN
-# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
-# The QuantumBlack Visual Analytics Limited ("QuantumBlack") name and logo
-# (either separately or in combination, "QuantumBlack Trademarks") are
-# trademarks of QuantumBlack. The License does not grant you any right or
-# license to the QuantumBlack Trademarks. You may not use the QuantumBlack
-# Trademarks or any confusingly similar mark as a trademark for your product,
-# or use the QuantumBlack Trademarks in any other manner that might cause
-# confusion in the marketplace, including but not limited to in advertising,
-# on websites, or on software.
-#
-# See the License for the specific language governing permissions and
-# limitations under the License.
-
 """Utilities for use with click."""
 import difflib
 import re
@@ -41,7 +13,7 @@ from contextlib import contextmanager
 from importlib import import_module
 from itertools import chain
 from pathlib import Path
-from typing import Dict, Iterable, List, Mapping, Sequence, Set, Tuple, Union
+from typing import Any, Dict, Iterable, List, Mapping, Sequence, Set, Tuple, Union
 
 import click
 import pkg_resources
@@ -241,7 +213,7 @@ def get_pkg_version(reqs_path: (Union[str, Path]), package_name: str) -> str:
         raise KedroCliError(f"Given path `{reqs_path}` is not a regular file.")
 
     pattern = re.compile(package_name + r"([^\w]|$)")
-    with reqs_path.open("r") as reqs_file:
+    with reqs_path.open("r", encoding="utf-8") as reqs_file:
         for req_line in reqs_file:
             req_line = req_line.strip()
             if pattern.search(req_line):
@@ -464,5 +436,81 @@ def _split_params(ctx, param, value):
                 f"cannot be an empty string."
             )
         value = item[1].strip()
-        result[key] = _try_convert_to_numeric(value)
+        result = _update_value_nested_dict(
+            result, _try_convert_to_numeric(value), key.split(".")
+        )
     return result
+
+
+def _update_value_nested_dict(
+    nested_dict: Dict[str, Any], value: Any, walking_path: List[str]
+) -> Dict:
+    """Update nested dict with value using walking_path as a parse tree to walk
+    down the nested dict.
+
+    Example:
+    ::
+        >>> nested_dict = {"foo": {"hello": "world", "bar": 1}}
+        >>> _update_value_nested_dict(nested_dict, value=2, walking_path=["foo", "bar"])
+        >>> print(nested_dict)
+        >>> {'foo': {'hello': 'world', 'bar': 2}}
+
+    Args:
+        nested_dict: dict to be updated
+        value: value to update the nested_dict with
+        walking_path: list of nested keys to use to walk down the nested_dict
+
+    Returns:
+        nested_dict updated with value at path `walking_path`
+    """
+    key = walking_path.pop(0)
+    if not walking_path:
+        nested_dict[key] = value
+        return nested_dict
+    nested_dict[key] = _update_value_nested_dict(
+        nested_dict.get(key, {}), value, walking_path
+    )
+    return nested_dict
+
+
+def _get_requirements_in(source_path: Path, create_empty: bool = False) -> Path:
+    """Get path to project level requirements.in, creating it if required.
+
+    Args:
+        source_path: Path to the project `src` folder.
+        create_empty: Whether an empty requirements.in file should be created if
+            requirements.in does not exist and there is also no requirements.txt to
+            copy requirements from.
+
+    Returns:
+        Path to requirements.in.
+
+    Raises:
+        FileNotFoundError: If neither requirements.in nor requirements.txt is found.
+
+    """
+    requirements_in = source_path / "requirements.in"
+    if requirements_in.is_file():
+        return requirements_in
+
+    requirements_txt = source_path / "requirements.txt"
+    if requirements_txt.is_file():
+        click.secho(
+            "No requirements.in found. Copying contents from requirements.txt..."
+        )
+        shutil.copyfile(str(requirements_txt), str(requirements_in))
+        return requirements_in
+
+    if create_empty:
+        click.secho("Creating empty requirements.in...")
+        requirements_in.touch()
+        return requirements_in
+
+    raise FileNotFoundError(
+        "No project requirements.in or requirements.txt found in `/src`. "
+        "Please create either and try again."
+    )
+
+
+def _get_values_as_tuple(values: Iterable[str]) -> Tuple[str, ...]:
+    return tuple(chain.from_iterable(value.split(",") for value in values))
