@@ -1,30 +1,3 @@
-# Copyright 2021 QuantumBlack Visual Analytics Limited
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
-# NONINFRINGEMENT. IN NO EVENT WILL THE LICENSOR OR OTHER CONTRIBUTORS
-# BE LIABLE FOR ANY CLAIM, DAMAGES, OR OTHER LIABILITY, WHETHER IN AN
-# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF, OR IN
-# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
-# The QuantumBlack Visual Analytics Limited ("QuantumBlack") name and logo
-# (either separately or in combination, "QuantumBlack Trademarks") are
-# trademarks of QuantumBlack. The License does not grant you any right or
-# license to the QuantumBlack Trademarks. You may not use the QuantumBlack
-# Trademarks or any confusingly similar mark as a trademark for your product,
-# or use the QuantumBlack Trademarks in any other manner that might cause
-# confusion in the marketplace, including but not limited to in advertising,
-# on websites, or on software.
-#
-# See the License for the specific language governing permissions and
-# limitations under the License.
 """This module provides context for Kedro project."""
 
 import functools
@@ -194,6 +167,24 @@ def _validate_layers_for_transcoding(catalog: DataCatalog) -> None:
         )
 
 
+def _update_nested_dict(old_dict: Dict[Any, Any], new_dict: Dict[Any, Any]) -> None:
+    """Update a nested dict with values of new_dict.
+
+    Args:
+        old_dict: dict to be updated
+        new_dict: dict to use for updating old_dict
+
+    """
+    for key, value in new_dict.items():
+        if key not in old_dict:
+            old_dict[key] = value
+        else:
+            if isinstance(old_dict[key], dict) and isinstance(value, dict):
+                _update_nested_dict(old_dict[key], value)
+            else:
+                old_dict[key] = value
+
+
 class KedroContext:
     """``KedroContext`` is the base class which holds the configuration and
     Kedro's main functionality.
@@ -344,7 +335,7 @@ class KedroContext:
         except MissingConfigException as exc:
             warn(f"Parameters not found in your Kedro project config.\n{str(exc)}")
             params = {}
-        params.update(self._extra_params or {})
+        _update_nested_dict(params, self._extra_params or {})
         return params
 
     def _get_catalog(
@@ -701,7 +692,7 @@ def load_context(project_path: Union[str, Path], **kwargs) -> KedroContext:
 
     Args:
         project_path: Path to the Kedro project.
-        kwargs: Optional kwargs for ``KedroContext`` class.
+        **kwargs: Optional kwargs for ``KedroContext`` class.
 
     Returns:
         Instance of ``KedroContext`` class defined in Kedro project.
