@@ -1,31 +1,3 @@
-# Copyright 2021 QuantumBlack Visual Analytics Limited
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
-# NONINFRINGEMENT. IN NO EVENT WILL THE LICENSOR OR OTHER CONTRIBUTORS
-# BE LIABLE FOR ANY CLAIM, DAMAGES, OR OTHER LIABILITY, WHETHER IN AN
-# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF, OR IN
-# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
-# The QuantumBlack Visual Analytics Limited ("QuantumBlack") name and logo
-# (either separately or in combination, "QuantumBlack Trademarks") are
-# trademarks of QuantumBlack. The License does not grant you any right or
-# license to the QuantumBlack Trademarks. You may not use the QuantumBlack
-# Trademarks or any confusingly similar mark as a trademark for your product,
-# or use the QuantumBlack Trademarks in any other manner that might cause
-# confusion in the marketplace, including but not limited to in advertising,
-# on websites, or on software.
-#
-# See the License for the specific language governing permissions and
-# limitations under the License.
-
 """This module provides a set of classes which underpin the data loading and
 saving functionality provided by ``kedro.io``.
 """
@@ -98,7 +70,9 @@ class AbstractDataSet(abc.ABC):
     """``AbstractDataSet`` is the base class for all data set implementations.
     All data set implementations should extend this abstract class
     and implement the methods marked as abstract.
-
+    If a specific dataset implementation cannot be used in conjunction with
+    the ``ParallelRunner``, such user-defined dataset should have the
+    attribute `_SINGLE_PROCESS = True`.
     Example:
     ::
 
@@ -169,8 +143,8 @@ class AbstractDataSet(abc.ABC):
             )
         except Exception as exc:
             raise DataSetError(
-                "An exception occurred when parsing config "
-                "for DataSet `{}`:\n{}".format(name, str(exc))
+                f"An exception occurred when parsing config "
+                f"for DataSet `{name}`:\n{str(exc)}"
             ) from exc
 
         try:
@@ -211,8 +185,8 @@ class AbstractDataSet(abc.ABC):
         except Exception as exc:
             # This exception handling is by design as the composed data sets
             # can throw any type of exception.
-            message = "Failed while loading data from data set {}.\n{}".format(
-                str(self), str(exc)
+            message = (
+                f"Failed while loading data from data set {str(self)}.\n{str(exc)}"
             )
             raise DataSetError(message) from exc
 
@@ -272,22 +246,22 @@ class AbstractDataSet(abc.ABC):
     @abc.abstractmethod
     def _load(self) -> Any:
         raise NotImplementedError(
-            "`{}` is a subclass of AbstractDataSet and"
-            "it must implement the `_load` method".format(self.__class__.__name__)
+            f"`{self.__class__.__name__}` is a subclass of AbstractDataSet and "
+            f"it must implement the `_load` method"
         )
 
     @abc.abstractmethod
     def _save(self, data: Any) -> None:
         raise NotImplementedError(
-            "`{}` is a subclass of AbstractDataSet and"
-            "it must implement the `_save` method".format(self.__class__.__name__)
+            f"`{self.__class__.__name__}` is a subclass of AbstractDataSet and "
+            f"it must implement the `_save` method"
         )
 
     @abc.abstractmethod
     def _describe(self) -> Dict[str, Any]:
         raise NotImplementedError(
-            "`{}` is a subclass of AbstractDataSet and"
-            "it must implement the `_describe` method".format(self.__class__.__name__)
+            f"`{self.__class__.__name__}` is a subclass of AbstractDataSet and "
+            f"it must implement the `_describe` method"
         )
 
     def exists(self) -> bool:
@@ -305,8 +279,8 @@ class AbstractDataSet(abc.ABC):
             self._logger.debug("Checking whether target of %s exists", str(self))
             return self._exists()
         except Exception as exc:
-            message = "Failed during exists check for data set {}.\n{}".format(
-                str(self), str(exc)
+            message = (
+                f"Failed during exists check for data set {str(self)}.\n{str(exc)}"
             )
             raise DataSetError(message) from exc
 
@@ -406,14 +380,16 @@ def parse_dataset_definition(
                 "`type` class path does not support relative "
                 "paths or paths ending with a dot."
             )
-
         class_paths = (prefix + class_obj for prefix in _DEFAULT_PACKAGES)
 
         trials = (_load_obj(class_path) for class_path in class_paths)
         try:
             class_obj = next(obj for obj in trials if obj is not None)
         except StopIteration as exc:
-            raise DataSetError(f"Class `{class_obj}` not found.") from exc
+            raise DataSetError(
+                f"Class `{class_obj}` not found or one of its dependencies"
+                f"has not been installed."
+            ) from exc
 
     if not issubclass(class_obj, AbstractDataSet):
         raise DataSetError(
@@ -430,7 +406,12 @@ def parse_dataset_definition(
         )
         logging.getLogger(__name__).warning(message, VERSION_KEY)
         del config[VERSION_KEY]
-    if config.pop(VERSIONED_FLAG_KEY, False):  # data set is versioned
+
+    # dataset is either versioned explicitly by the user or versioned is set to true by default
+    # on the dataset
+    if config.pop(VERSIONED_FLAG_KEY, False) or getattr(
+        class_obj, VERSIONED_FLAG_KEY, False
+    ):
         config[VERSION_KEY] = Version(load_version, save_version)
 
     return class_obj, config
@@ -600,8 +581,8 @@ class AbstractVersionedDataSet(AbstractDataSet, abc.ABC):
 
         if self._exists_function(str(versioned_path)):
             raise DataSetError(
-                "Save path `{}` for {} must not exist if versioning "
-                "is enabled.".format(versioned_path, str(self))
+                f"Save path `{versioned_path}` for {str(self)} must not exist if "
+                f"versioning is enabled."
             )
 
         return versioned_path
@@ -656,8 +637,8 @@ class AbstractVersionedDataSet(AbstractDataSet, abc.ABC):
         except VersionNotFoundError:
             return False
         except Exception as exc:  # SKIP_IF_NO_SPARK
-            message = "Failed during exists check for data set {}.\n{}".format(
-                str(self), str(exc)
+            message = (
+                f"Failed during exists check for data set {str(self)}.\n{str(exc)}"
             )
             raise DataSetError(message) from exc
 
@@ -691,7 +672,7 @@ def _parse_filepath(filepath: str) -> Dict[str, str]:
     if protocol == "file":
         windows_path = re.match(r"^/([a-zA-Z])[:|]([\\/].*)$", path)
         if windows_path:
-            path = "{}:{}".format(*windows_path.groups())
+            path = ":".join(windows_path.groups())
 
     options = {"protocol": protocol, "path": path}
 
@@ -723,7 +704,7 @@ def get_protocol_and_path(filepath: str, version: Version = None) -> Tuple[str,
     protocol = options_dict["protocol"]
 
     if protocol in HTTP_PROTOCOLS:
-        if version:
+        if version is not None:
             raise DataSetError(
                 "HTTP(s) DataSet doesn't support versioning. "
                 "Please remove version flag from the dataset configuration."
