@@ -1,34 +1,7 @@
-# Copyright 2021 QuantumBlack Visual Analytics Limited
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
-# NONINFRINGEMENT. IN NO EVENT WILL THE LICENSOR OR OTHER CONTRIBUTORS
-# BE LIABLE FOR ANY CLAIM, DAMAGES, OR OTHER LIABILITY, WHETHER IN AN
-# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF, OR IN
-# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
-# The QuantumBlack Visual Analytics Limited ("QuantumBlack") name and logo
-# (either separately or in combination, "QuantumBlack Trademarks") are
-# trademarks of QuantumBlack. The License does not grant you any right or
-# license to the QuantumBlack Trademarks. You may not use the QuantumBlack
-# Trademarks or any confusingly similar mark as a trademark for your product,
-# or use the QuantumBlack Trademarks in any other manner that might cause
-# confusion in the marketplace, including but not limited to in advertising,
-# on websites, or on software.
-#
-# See the License for the specific language governing permissions and
-# limitations under the License.
-
 """A ``DataCatalog`` with a default ``DataSet`` implementation for any data set
 which is not registered in the catalog.
 """
+import warnings
 from typing import Any, Callable, Dict, Optional
 
 from kedro.io.core import AbstractDataSet
@@ -47,7 +20,8 @@ class DataCatalogWithDefault(DataCatalog):
         default: Callable[[str], AbstractDataSet] = None,
         remember: bool = False,
     ):
-        """A ``DataCatalog`` with a default ``DataSet`` implementation for any
+        """``DataCatalogWithDefault`` is deprecated and will be removed in Kedro 0.18.0.
+        A ``DataCatalog`` with a default ``DataSet`` implementation for any
         data set which is not registered in the catalog.
 
         Args:
@@ -83,6 +57,13 @@ class DataCatalogWithDefault(DataCatalog):
         """
         super().__init__(data_sets)
 
+        warnings.warn(
+            "`DataCatalogWithDefault` is now deprecated and will be removed in Kedro 0.18.0."
+            "For more information, please visit "
+            "https://github.com/quantumblacklabs/kedro/blob/main/RELEASE.md",
+            DeprecationWarning,
+        )
+
         if not callable(default):
             raise TypeError(
                 "Default must be a callable with a single input "
