@@ -1,30 +1,3 @@
-# Copyright 2021 QuantumBlack Visual Analytics Limited
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
-# NONINFRINGEMENT. IN NO EVENT WILL THE LICENSOR OR OTHER CONTRIBUTORS
-# BE LIABLE FOR ANY CLAIM, DAMAGES, OR OTHER LIABILITY, WHETHER IN AN
-# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF, OR IN
-# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
-# The QuantumBlack Visual Analytics Limited ("QuantumBlack") name and logo
-# (either separately or in combination, "QuantumBlack Trademarks") are
-# trademarks of QuantumBlack. The License does not grant you any right or
-# license to the QuantumBlack Trademarks. You may not use the QuantumBlack
-# Trademarks or any confusingly similar mark as a trademark for your product,
-# or use the QuantumBlack Trademarks in any other manner that might cause
-# confusion in the marketplace, including but not limited to in advertising,
-# on websites, or on software.
-#
-# See the License for the specific language governing permissions and
-# limitations under the License.
 """This module provides user-friendly functions for creating nodes as parts
 of Kedro pipelines.
 """
@@ -135,6 +108,14 @@ class Node:  # pylint: disable=too-many-instance-attributes
         self._name = name
         self._namespace = namespace
         self._tags = set(_to_list(tags))
+        if decorators:
+            warn(
+                "The node's `decorators` API will be deprecated in Kedro 0.18.0."
+                "Please use a node's Hooks to extend the node's behaviour in a pipeline."
+                "For more information, please visit"
+                "https://kedro.readthedocs.io/en/stable/07_extend_kedro/02_hooks.html",
+                DeprecationWarning,
+            )
         self._decorators = list(decorators or [])
 
         self._validate_unique_outputs()
@@ -166,6 +147,9 @@ class Node:  # pylint: disable=too-many-instance-attributes
     def _unique_key(self):
         def hashable(value):
             if isinstance(value, dict):
+                # we sort it because a node with inputs/outputs
+                # {"arg1": "a", "arg2": "b"} is equivalent to
+                # a node with inputs/outputs {"arg2": "b", "arg1": "a"}
                 return tuple(sorted(value.items()))
             if isinstance(value, list):
                 return tuple(value)
@@ -187,18 +171,19 @@ class Node:  # pylint: disable=too-many-instance-attributes
         return hash(self._unique_key)
 
     def __str__(self):
-        def _sorted_set_to_str(xset):
-            return f"[{','.join(sorted(xset))}]"
+        def _set_to_str(xset):
+            return f"[{','.join(xset)}]"
 
-        out_str = _sorted_set_to_str(self.outputs) if self._outputs else "None"
-        in_str = _sorted_set_to_str(self.inputs) if self._inputs else "None"
+        out_str = _set_to_str(self.outputs) if self._outputs else "None"
+        in_str = _set_to_str(self.inputs) if self._inputs else "None"
 
         prefix = self._name + ": " if self._name else ""
         return prefix + f"{self._func_name}({in_str}) -> {out_str}"
 
     def __repr__(self):  # pragma: no cover
-        return "Node({}, {!r}, {!r}, {!r})".format(
-            self._func_name, self._inputs, self._outputs, self._name
+        return (
+            f"Node({self._func_name}, {repr(self._inputs)}, {repr(self._outputs)}, "
+            f"{repr(self._name)})"
         )
 
     def __call__(self, **kwargs) -> Dict[str, Any]:
@@ -334,7 +319,7 @@ class Node:  # pylint: disable=too-many-instance-attributes
         new ``Node`` object, but with no changes to the function.
 
         Args:
-            decorators: Decorators to be applied on the node function.
+            *decorators: Decorators to be applied on the node function.
                 Decorators will be applied from right to left.
 
         Returns:
@@ -404,7 +389,7 @@ class Node:  # pylint: disable=too-many-instance-attributes
             "The node's `decorate` API will be deprecated in Kedro 0.18.0."
             "Please use a node's Hooks to extend the node's behaviour in a pipeline."
             "For more information, please visit"
-            "https://kedro.readthedocs.io/en/stable/07_extend_kedro/04_hooks.html",
+            "https://kedro.readthedocs.io/en/stable/07_extend_kedro/02_hooks.html",
             DeprecationWarning,
         )
         return self._copy(decorators=self._decorators + list(reversed(decorators)))
@@ -448,7 +433,7 @@ class Node:  # pylint: disable=too-many-instance-attributes
             )
 
         try:
-            inputs = dict() if inputs is None else inputs
+            inputs = {} if inputs is None else inputs
             if not self._inputs:
                 outputs = self._run_with_no_inputs(inputs)
             elif isinstance(self._inputs, str):
@@ -468,10 +453,9 @@ class Node:  # pylint: disable=too-many-instance-attributes
     def _run_with_no_inputs(self, inputs: Dict[str, Any]):
         if inputs:
             raise ValueError(
-                "Node {} expected no inputs, "
-                "but got the following {} input(s) instead: {}".format(
-                    str(self), len(inputs), list(sorted(inputs.keys()))
-                )
+                f"Node {str(self)} expected no inputs, "
+                f"but got the following {len(inputs)} input(s) instead: "
+                f"{sorted(inputs.keys())}."
             )
 
         return self._decorated_func()
@@ -479,10 +463,9 @@ class Node:  # pylint: disable=too-many-instance-attributes
     def _run_with_one_input(self, inputs: Dict[str, Any], node_input: str):
         if len(inputs) != 1 or node_input not in inputs:
             raise ValueError(
-                "Node {} expected one input named '{}', "
-                "but got the following {} input(s) instead: {}".format(
-                    str(self), node_input, len(inputs), list(sorted(inputs.keys()))
-                )
+                f"Node {str(self)} expected one input named '{node_input}', "
+                f"but got the following {len(inputs)} input(s) instead: "
+                f"{sorted(inputs.keys())}."
             )
 
         return self._decorated_func(inputs[node_input])
@@ -491,30 +474,21 @@ class Node:  # pylint: disable=too-many-instance-attributes
         # Node inputs and provided run inputs should completely overlap
         if set(node_inputs) != set(inputs.keys()):
             raise ValueError(
-                "Node {} expected {} input(s) {}, "
-                "but got the following {} input(s) instead: {}.".format(
-                    str(self),
-                    len(node_inputs),
-                    node_inputs,
-                    len(inputs),
-                    list(sorted(inputs.keys())),
-                )
+                f"Node {str(self)} expected {len(node_inputs)} input(s) {node_inputs}, "
+                f"but got the following {len(inputs)} input(s) instead: "
+                f"{sorted(inputs.keys())}."
             )
         # Ensure the function gets the inputs in the correct order
-        return self._decorated_func(*[inputs[item] for item in node_inputs])
+        return self._decorated_func(*(inputs[item] for item in node_inputs))
 
     def _run_with_dict(self, inputs: Dict[str, Any], node_inputs: Dict[str, str]):
         # Node inputs and provided run inputs should completely overlap
         if set(node_inputs.values()) != set(inputs.keys()):
             raise ValueError(
-                "Node {} expected {} input(s) {}, "
-                "but got the following {} input(s) instead: {}.".format(
-                    str(self),
-                    len(set(node_inputs.values())),
-                    list(sorted(set(node_inputs.values()))),
-                    len(inputs),
-                    list(sorted(inputs.keys())),
-                )
+                f"Node {str(self)} expected {len(set(node_inputs.values()))} input(s) "
+                f"{sorted(set(node_inputs.values()))}, "
+                f"but got the following {len(inputs)} input(s) instead: "
+                f"{sorted(inputs.keys())}."
             )
         kwargs = {arg: inputs[alias] for arg, alias in node_inputs.items()}
         return self._decorated_func(**kwargs)
@@ -523,30 +497,26 @@ class Node:  # pylint: disable=too-many-instance-attributes
         def _from_dict():
             if set(self._outputs.keys()) != set(outputs.keys()):
                 raise ValueError(
-                    "Failed to save outputs of node {}.\n"
-                    "The node's output keys {} do not "
-                    "match with the returned output's keys {}.".format(
-                        str(self), set(outputs.keys()), set(self._outputs.keys())
-                    )
+                    f"Failed to save outputs of node {str(self)}.\n"
+                    f"The node's output keys {set(outputs.keys())} do not match with "
+                    f"the returned output's keys {set(self._outputs.keys())}."
                 )
             return {name: outputs[key] for key, name in self._outputs.items()}
 
         def _from_list():
             if not isinstance(outputs, (list, tuple)):
                 raise ValueError(
-                    "Failed to save outputs of node {}.\n"
-                    "The node definition contains a list of "
-                    "outputs {}, whereas the node function "
-                    "returned a `{}`.".format(
-                        str(self), self._outputs, type(outputs).__name__
-                    )
+                    f"Failed to save outputs of node {str(self)}.\n"
+                    f"The node definition contains a list of "
+                    f"outputs {self._outputs}, whereas the node function "
+                    f"returned a `{type(outputs).__name__}`."
                 )
             if len(outputs) != len(self._outputs):
                 raise ValueError(
-                    "Failed to save outputs of node {}.\n"
-                    "The node function returned {} output(s), "
-                    "whereas the node definition contains {} "
-                    "output(s).".format(str(self), len(outputs), len(self._outputs))
+                    f"Failed to save outputs of node {str(self)}.\n"
+                    f"The node function returned {len(outputs)} output(s), "
+                    f"whereas the node definition contains {len(self._outputs)} "
+                    f"output(s)."
                 )
 
             return dict(zip(self._outputs, outputs))
@@ -618,9 +588,9 @@ class Node:  # pylint: disable=too-many-instance-attributes
 
 def _node_error_message(msg) -> str:
     return (
-        "Invalid Node definition: {}\n"
-        "Format should be: node(function, inputs, outputs)"
-    ).format(msg)
+        f"Invalid Node definition: {msg}\n"
+        f"Format should be: node(function, inputs, outputs)"
+    )
 
 
 def node(
@@ -719,7 +689,7 @@ def _to_list(element: Union[None, str, Iterable[str], Dict[str, str]]) -> List[s
     if isinstance(element, str):
         return [element]
     if isinstance(element, dict):
-        return sorted(element.values())
+        return list(element.values())
     return list(element)
 
 
