@@ -1,30 +1,3 @@
-# Copyright 2021 QuantumBlack Visual Analytics Limited
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
-# NONINFRINGEMENT. IN NO EVENT WILL THE LICENSOR OR OTHER CONTRIBUTORS
-# BE LIABLE FOR ANY CLAIM, DAMAGES, OR OTHER LIABILITY, WHETHER IN AN
-# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF, OR IN
-# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
-# The QuantumBlack Visual Analytics Limited ("QuantumBlack") name and logo
-# (either separately or in combination, "QuantumBlack Trademarks") are
-# trademarks of QuantumBlack. The License does not grant you any right or
-# license to the QuantumBlack Trademarks. You may not use the QuantumBlack
-# Trademarks or any confusingly similar mark as a trademark for your product,
-# or use the QuantumBlack Trademarks in any other manner that might cause
-# confusion in the marketplace, including but not limited to in advertising,
-# on websites, or on software.
-#
-# See the License for the specific language governing permissions and
-# limitations under the License.
 """A ``Pipeline`` is a collection of ``Node`` objects which can be executed as
 a Directed Acyclic Graph, sequentially or in parallel. The ``Pipeline`` class
 offers quick access to input dependencies,
@@ -60,9 +33,8 @@ def _transcode_split(element: str) -> Tuple[str, str]:
 
     if len(split_name) > 2:
         raise ValueError(
-            "Expected maximum 1 transcoding separator, found {} instead: '{}'.".format(
-                len(split_name) - 1, element
-            )
+            f"Expected maximum 1 transcoding separator, found {len(split_name) - 1} "
+            f"instead: '{element}'."
         )
     if len(split_name) == 1:
         split_name.append("")
@@ -200,9 +172,8 @@ class Pipeline:  # pylint: disable=too-many-public-methods
         nodes_reprs = [repr(node) for node in self.nodes[:max_nodes_to_display]]
         if len(self.nodes) > max_nodes_to_display:
             nodes_reprs.append("...")
-        nodes_reprs_str = (
-            "[\n{}\n]".format(",\n".join(nodes_reprs)) if nodes_reprs else "[]"
-        )
+        sep = ",\n"
+        nodes_reprs_str = f"[\n{sep.join(nodes_reprs)}\n]" if nodes_reprs else "[]"
         constructor_repr = f"({nodes_reprs_str})"
         return f"{self.__class__.__name__}{constructor_repr}"
 
@@ -211,6 +182,11 @@ class Pipeline:  # pylint: disable=too-many-public-methods
             return NotImplemented
         return Pipeline(set(self.nodes + other.nodes))
 
+    def __radd__(self, other):
+        if isinstance(other, int) and other == 0:
+            return self
+        return self.__add__(other)
+
     def __sub__(self, other):
         if not isinstance(other, Pipeline):
             return NotImplemented
@@ -233,7 +209,7 @@ class Pipeline:  # pylint: disable=too-many-public-methods
             All node input names as a Set.
 
         """
-        return set.union(set(), *[node.inputs for node in self.nodes])
+        return set.union(set(), *(node.inputs for node in self.nodes))
 
     def all_outputs(self) -> Set[str]:
         """All outputs of all nodes in the pipeline.
@@ -242,7 +218,7 @@ class Pipeline:  # pylint: disable=too-many-public-methods
             All node outputs.
 
         """
-        return set.union(set(), *[node.outputs for node in self.nodes])
+        return set.union(set(), *(node.outputs for node in self.nodes))
 
     def _remove_intermediates(self, datasets: Set[str]) -> Set[str]:
         intermediate = {_strip_transcoding(i) for i in self.all_inputs()} & {
@@ -393,7 +369,7 @@ class Pipeline:  # pylint: disable=too-many-public-methods
         nodes by name.
 
         Args:
-            node_names: One or more node names. The returned ``Pipeline``
+            *node_names: One or more node names. The returned ``Pipeline``
                 will only contain these nodes.
 
         Raises:
@@ -433,9 +409,8 @@ class Pipeline:  # pylint: disable=too-many-public-methods
         ]
         if not nodes:
             raise ValueError(
-                "Pipeline does not contain nodes with namespace(s) {}.".format(
-                    list(node_namespace)
-                )
+                f"Pipeline does not contain nodes with namespace(s) "
+                f"{list(node_namespace)}."
             )
         return Pipeline(nodes)
 
@@ -511,7 +486,7 @@ class Pipeline:  # pylint: disable=too-many-public-methods
         matches to the fully-qualified name only (i.e. name@format).
 
         Args:
-            inputs: A list of inputs which should be used as a starting
+            *inputs: A list of inputs which should be used as a starting
                 point of the new ``Pipeline``.
 
         Raises:
@@ -537,7 +512,7 @@ class Pipeline:  # pylint: disable=too-many-public-methods
         matches to the fully-qualified name only (i.e. name@format).
 
         Args:
-            inputs: A list of inputs which should be used as a starting point
+            *inputs: A list of inputs which should be used as a starting point
                 of the new ``Pipeline``
 
         Raises:
@@ -577,7 +552,7 @@ class Pipeline:  # pylint: disable=too-many-public-methods
         to the fully-qualified name only (i.e. name@format).
 
         Args:
-            outputs: A list of outputs which should be the final outputs
+            *outputs: A list of outputs which should be the final outputs
                 of the new ``Pipeline``.
 
         Raises:
@@ -602,7 +577,7 @@ class Pipeline:  # pylint: disable=too-many-public-methods
         to the fully-qualified name only (i.e. name@format).
 
         Args:
-            outputs: A list of outputs which should be the final outputs of
+            *outputs: A list of outputs which should be the final outputs of
                 the new ``Pipeline``.
 
         Raises:
@@ -638,7 +613,7 @@ class Pipeline:  # pylint: disable=too-many-public-methods
         directly or transitively on the provided nodes.
 
         Args:
-            node_names: A list of node_names which should be used as a
+            *node_names: A list of node_names which should be used as a
                 starting point of the new ``Pipeline``.
         Raises:
             ValueError: Raised when any of the given names do not exist in the
@@ -659,7 +634,7 @@ class Pipeline:  # pylint: disable=too-many-public-methods
         or transitively by the provided nodes.
 
         Args:
-            node_names: A list of node_names which should be used as an
+            *node_names: A list of node_names which should be used as an
                 end point of the new ``Pipeline``.
         Raises:
             ValueError: Raised when any of the given names do not exist in the
@@ -681,7 +656,7 @@ class Pipeline:  # pylint: disable=too-many-public-methods
         are provided.
 
         Args:
-            tags: A list of node tags which should be used to lookup
+            *tags: A list of node tags which should be used to lookup
                 the nodes of the new ``Pipeline``.
         Returns:
             Pipeline: A new ``Pipeline`` object, containing a subset of the
@@ -698,7 +673,7 @@ class Pipeline:  # pylint: disable=too-many-public-methods
         return a copy of the current ``Pipeline`` object.
 
         Args:
-            decorators: Decorators to be applied on all node functions in
+            *decorators: Decorators to be applied on all node functions in
                 the pipeline, always applied from right to left.
 
         Returns:
@@ -710,7 +685,7 @@ class Pipeline:  # pylint: disable=too-many-public-methods
             "The pipeline's `decorate` API will be deprecated in Kedro 0.18.0."
             "Please use a node's Hooks to extend the node's behaviour in a pipeline."
             "For more information, please visit"
-            "https://kedro.readthedocs.io/en/stable/07_extend_kedro/04_hooks.html",
+            "https://kedro.readthedocs.io/en/stable/07_extend_kedro/02_hooks.html",
             DeprecationWarning,
         )
         nodes = [node.decorate(*decorators) for node in self.nodes]
@@ -785,8 +760,8 @@ def _validate_unique_outputs(nodes: List[Node]) -> None:
     duplicates = [key for key, value in Counter(outputs).items() if value > 1]
     if duplicates:
         raise OutputNotUniqueError(
-            "Output(s) {} are returned by more than one nodes. Node "
-            "outputs must be unique.".format(sorted(duplicates))
+            f"Output(s) {sorted(duplicates)} are returned by more than one nodes. Node "
+            f"outputs must be unique."
         )
 
 
@@ -796,8 +771,8 @@ def _validate_unique_confirms(nodes: List[Node]) -> None:
     duplicates = [key for key, value in Counter(confirms).items() if value > 1]
     if duplicates:
         raise ConfirmNotUniqueError(
-            "{} datasets are confirmed by more than one node. Node "
-            "confirms must be unique.".format(sorted(duplicates))
+            f"{sorted(duplicates)} datasets are confirmed by more than one node. Node "
+            f"confirms must be unique."
         )
 
 
@@ -820,10 +795,10 @@ def _validate_transcoded_inputs_outputs(nodes: List[Node]) -> None:
 
     if invalid:
         raise ValueError(
-            "The following datasets are used with transcoding, but "
-            "were referenced without the separator: {}.\n"
-            "Please specify a transcoding option or "
-            "rename the datasets.".format(", ".join(invalid))
+            f"The following datasets are used with transcoding, but "
+            f"were referenced without the separator: {', '.join(invalid)}.\n"
+            f"Please specify a transcoding option or "
+            f"rename the datasets."
         )
 
 
