@@ -1,30 +1,3 @@
-# Copyright 2021 QuantumBlack Visual Analytics Limited
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
-# NONINFRINGEMENT. IN NO EVENT WILL THE LICENSOR OR OTHER CONTRIBUTORS
-# BE LIABLE FOR ANY CLAIM, DAMAGES, OR OTHER LIABILITY, WHETHER IN AN
-# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF, OR IN
-# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
-# The QuantumBlack Visual Analytics Limited ("QuantumBlack") name and logo
-# (either separately or in combination, "QuantumBlack Trademarks") are
-# trademarks of QuantumBlack. The License does not grant you any right or
-# license to the QuantumBlack Trademarks. You may not use the QuantumBlack
-# Trademarks or any confusingly similar mark as a trademark for your product,
-# or use the QuantumBlack Trademarks in any other manner that might cause
-# confusion in the marketplace, including but not limited to in advertising,
-# on websites, or on software.
-#
-# See the License for the specific language governing permissions and
-# limitations under the License.
 """``ParallelRunner`` is an ``AbstractRunner`` implementation. It can
 be used to run the ``Pipeline`` in parallel groups formed by toposort.
 """
@@ -136,7 +109,7 @@ def _run_node_synchronization(  # pylint: disable=too-many-arguments
 
     """
     if multiprocessing.get_start_method() == "spawn" and package_name:  # type: ignore
-        conf_logging = conf_logging or dict()
+        conf_logging = conf_logging or {}
         _bootstrap_subprocess(package_name, conf_logging)
 
     return run_node(node, catalog, is_async, run_id)
@@ -145,6 +118,9 @@ def _run_node_synchronization(  # pylint: disable=too-many-arguments
 class ParallelRunner(AbstractRunner):
     """``ParallelRunner`` is an ``AbstractRunner`` implementation. It can
     be used to run the ``Pipeline`` in parallel groups formed by toposort.
+    Please note that this `runner` implementation validates dataset using the
+    ``_validate_catalog`` method, which checks if any of the datasets are
+    single process only using the `_SINGLE_PROCESS` dataset attribute.
     """
 
     def __init__(self, max_workers: int = None, is_async: bool = False):
@@ -164,7 +140,7 @@ class ParallelRunner(AbstractRunner):
         """
         super().__init__(is_async=is_async)
         self._manager = ParallelRunnerManager()
-        self._manager.start()
+        self._manager.start()  # pylint: disable=consider-using-with
 
         # This code comes from the concurrent.futures library
         # https://github.com/python/cpython/blob/master/Lib/concurrent/futures/process.py#L588
@@ -207,12 +183,12 @@ class ParallelRunner(AbstractRunner):
 
         if unserializable:
             raise AttributeError(
-                "The following nodes cannot be serialized: {}\nIn order to "
-                "utilize multiprocessing you need to make sure all nodes are "
-                "serializable, i.e. nodes should not include lambda "
-                "functions, nested functions, closures, etc.\nIf you "
-                "are using custom decorators ensure they are correctly using "
-                "functools.wraps().".format(sorted(unserializable))
+                f"The following nodes cannot be serialized: {sorted(unserializable)}\n"
+                f"In order to utilize multiprocessing you need to make sure all nodes "
+                f"are serializable, i.e. nodes should not include lambda "
+                f"functions, nested functions, closures, etc.\nIf you "
+                f"are using custom decorators ensure they are correctly using "
+                f"functools.wraps()."
             )
 
     @classmethod
@@ -236,12 +212,12 @@ class ParallelRunner(AbstractRunner):
 
         if unserializable:
             raise AttributeError(
-                "The following data sets cannot be used with multiprocessing: "
-                "{}\nIn order to utilize multiprocessing you need to make sure "
-                "all data sets are serializable, i.e. data sets should not make "
-                "use of lambda functions, nested functions, closures etc.\nIf you "
-                "are using custom decorators ensure they are correctly using "
-                "functools.wraps().".format(sorted(unserializable))
+                f"The following data sets cannot be used with multiprocessing: "
+                f"{sorted(unserializable)}\nIn order to utilize multiprocessing you "
+                f"need to make sure all data sets are serializable, i.e. data sets "
+                f"should not make use of lambda functions, nested functions, closures "
+                f"etc.\nIf you are using custom decorators ensure they are correctly "
+                f"using functools.wraps()."
             )
 
         memory_data_sets = []
@@ -255,9 +231,10 @@ class ParallelRunner(AbstractRunner):
 
         if memory_data_sets:
             raise AttributeError(
-                "The following data sets are memory data sets: {}\n"
-                "ParallelRunner does not support output to externally created "
-                "MemoryDataSets".format(sorted(memory_data_sets))
+                f"The following data sets are memory data sets: "
+                f"{sorted(memory_data_sets)}\n"
+                f"ParallelRunner does not support output to externally created "
+                f"MemoryDataSets"
             )
 
     def _get_required_workers_count(self, pipeline: Pipeline):
@@ -307,9 +284,10 @@ class ParallelRunner(AbstractRunner):
         done = None
         max_workers = self._get_required_workers_count(pipeline)
 
+        from kedro.framework.project import PACKAGE_NAME
+
         session = get_current_session(silent=True)
         # pylint: disable=protected-access
-        package_name = session._package_name if session else None
         conf_logging = session._get_logging_config() if session else None
 
         with ProcessPoolExecutor(max_workers=max_workers) as pool:
@@ -324,7 +302,7 @@ class ParallelRunner(AbstractRunner):
                             catalog,
                             self._is_async,
                             run_id,
-                            package_name=package_name,
+                            package_name=PACKAGE_NAME,
                             conf_logging=conf_logging,
                         )
                     )
